const babel = require("rollup-plugin-babel");
const commonjs = require("rollup-plugin-commonjs");
const nodeResolve = require("rollup-plugin-node-resolve");
const postcss = require("rollup-plugin-postcss");
const autoprefixer = require("autoprefixer");
const cssnano = require("cssnano");
const replace = require("rollup-plugin-replace");
const { uglify } = require("rollup-plugin-uglify");
const version = require("./package.json").version;
const isProd = process.env.NODE_ENV === "production";

export default {
  input: "src/index.js",
  output: {
    name: "artplayer",
    file: isProd ? "dist/artplayer.js" : "docs/js/artplayer.js",
    format: "umd"
  },
  plugins: [
    postcss({
      plugins: [autoprefixer, cssnano],
      extract: isProd ? "dist/artplayer.css" : "docs/css/artplayer.css"
    }),
    nodeResolve(),
    commonjs(),
    babel({
      runtimeHelpers: true,
      exclude: "node_modules/**",
      plugins: ["@babel/external-helpers", "@babel/transform-runtime"]
    }),
    replace({
      exclude: "node_modules/**",
      __ENV__: JSON.stringify(process.env.NODE_ENV || "development"),
      __VERSION__: version
    }),
    isProd && uglify()
  ]
};
